@@ -200,6 +200,7 @@ class Incident(CanaryToolsBase):
         **Attributes:**
             - **id (str)** -- The identification code of the incident
             - **description (str)** -- The event description of the incident
+            - **flock_id (str)** -- The id of the flock this incident belongs to
             - **acknowledged (bool)** -- Has the incident been acknowledged?
             - **events (list)** -- List of events
             - **logtype (str)** -- Log type
@@ -227,7 +228,7 @@ class Incident(CanaryToolsBase):
         # Set only specified fields as attributes
         if key not in ['console', 'id', 'description', 'summary', 'logtype', 'events', \
                        'acknowledged', 'dst_host', 'src_host', 'node_id', 'dst_port', \
-                       'src_port', 'created_std', 'updated_std']:
+                       'src_port', 'created_std', 'updated_std', 'flock_id']:
             return
 
         # if the key is events parse list of events parse events
